Desraj estimator computes the estimated value of a finite population
total when values of the study variable for the sampled units
and the corresponding selection probabilities are given as per the order
of selection. It is meant for use in Probability Proportional to Size
Without Replacement Sampling Scheme.
Usage
desraj(y, p)
Arguments
y
vector of vaues of sampled units as per the order of selection
p
vector of selection probabilities as per the order of selection
References
Sampath,S.(2005) Sampling Theory and Methods,Alpha Science International, Ltd